@@ -79,7 +79,7 @@ class Server(object):
             packet.Packet.json = json
             engineio_options['json'] = json
         engineio_options['async_handlers'] = False
-        self.eio = engineio.Server(**engineio_options)
+        self.eio = self._engineio_server_class()(**engineio_options)
         self.eio.on('connect', self._handle_eio_connect)
         self.eio.on('message', self._handle_eio_message)
         self.eio.on('disconnect', self._handle_eio_disconnect)
@@ -106,12 +106,16 @@ class Server(object):
         if client_manager is None:
             client_manager = base_manager.BaseManager()
         self.manager = client_manager
+        self.manager.set_server(self)
         self.manager_initialized = False
 
         self.async_handlers = async_handlers
 
         self.async_mode = self.eio.async_mode
 
+    def is_asyncio_based(self):
+        return False
+
     def on(self, event, handler=None, namespace=None):
         """Register an event handler.
 
@@ -170,6 +174,8 @@ class Server(object):
         """
         if not isinstance(namespace_handler, namespace.Namespace):
             raise ValueError('Not a namespace instance')
+        if self.is_asyncio_based() != namespace_handler.is_asyncio_based():
+            raise ValueError('Not a valid namespace class for this server')
         namespace_handler._set_server(self)
         self.namespace_handlers[namespace_handler.namespace] = \
             namespace_handler
@@ -344,9 +350,6 @@ class Server(object):
         This function returns the HTTP response body to deliver to the client
         as a byte sequence.
         """
-        if not self.manager_initialized:
-            self.manager_initialized = True
-            self.manager.initialize(self)
         return self.eio.handle_request(environ, start_response)
 
     def start_background_task(self, target, *args, **kwargs):
@@ -484,6 +487,9 @@ class Server(object):
 
     def _handle_eio_connect(self, sid, environ):
         """Handle the Engine.IO connection event."""
+        if not self.manager_initialized:
+            self.manager_initialized = True
+            self.manager.initialize()
         self.environ[sid] = environ
         return self._handle_connect(sid, '/')
 
@@ -518,3 +524,6 @@ class Server(object):
     def _handle_eio_disconnect(self, sid):
         """Handle Engine.IO disconnect event."""
         self._handle_disconnect(sid, '/')
+
+    def _engineio_server_class(self):
+        return engineio.Server
